@@ -177,13 +177,22 @@ class Trigger(object):
         #TODO: use a tag driver
         timestamp = datetime.now().strftime('%Y%m%d-%H%M%S')
         try:
-            tag_format = '{0}-{1}-{2}'.format(self.conf.config['repo-name'],
+            repo_name = self.conf.config['deploy.repo-name']
+            tag_format = '{0}-{1}-{2}'.format(repo_name,
                                               tag_type,
                                               timestamp)
             return self.conf.repo.create_tag(tag_format)
         except GitCommandError:
-            message = 'Failed to write the {0} tag.'.format(tag_type)
-            raise TriggerError(message, 190)
+            if tag_type == 'start':
+                try:
+                    self.conf.repo.head.object
+                except ValueError:
+                    msg = ('There is no initial commit, so no start tag can be'
+                           ' written. Please add at least one commit before'
+                           ' attempting to start a deployment.')
+                    raise TriggerError(msg, 191)
+            msg = 'Failed to write the {0} tag.'.format(tag_type)
+            raise TriggerError(msg, 190)
 
     def _get_latest_tag(self, tag_type):
         tag_filter = '-{0}-'.format(tag_type)
@@ -231,10 +240,14 @@ class Trigger(object):
         try:
             deploy_info = self._sync_driver.get_deploy_info()
             tag = deploy_info['tag']
-        except (SyncDriverError, KeyError):
+        except SyncDriverError as e:
             LOG.error(e.message)
             raise TriggerError('Failed to read deployment file. Has an initial'
                                ' deploment occurred?.', 211)
+        except KeyError:
+            LOG.error(e.message)
+            raise TriggerError('Tag not in deployment file. Has an initial'
+                               ' deploment occurred?.', 212)
         try:
             if args.action == 'sync':
                 self._report_driver.report_sync(tag, detailed=args.detailed)
@@ -332,12 +345,38 @@ class Trigger(object):
         self.command_name = name[4:]
         self.extensions = self._discover_extensions()
         self.parser = self._get_subcommand_parser()
+        if len(argv) == 0:
+            self.parser.print_help()
+            raise SystemExit(2)
         args = self.parser.parse_args(argv)
-
+        if args.func == self.do_help:
+            self.do_help(args)
+            raise SystemExit(0)
+        try:
+            self.conf.check_config()
+        except ConfigurationError as e:
+            LOG.error(e.message)
+            raise SystemExit(e.errorno)
+        umask = self.conf.config['deploy.required-umask']
+        if umask:
+            # When the config is set, it'll be in octal, but users may or may
+            # not set it as a string. If it isn't a string, GitPython will read
+            # it in as an int, so we need to convert that properly to a string,
+            # then to int by treating the string as octal.
+            if isinstance(umask, str):
+                _umask = int(umask, 8)
+            else:
+                _umask = int(str(umask), 8)
+            # os.umask annoyingly is the only way to get the current umask and
+            # it sets the umask. Get the umask and return it to the original.
+            current_umask = os.umask(_umask)
+            os.umask(current_umask)
+            if current_umask != _umask:
+                msg = ('Required umask is {0:03d}. Please set your umask and'
+                       ' try again.')
+                LOG.error(msg.format(umask))
+                raise SystemExit(220)
         try:
-            if args.func == self.do_help:
-                self.do_help(args)
-                return 0
             args.func(args)
         except TriggerError as e:
             LOG.error(e.message)
@@ -345,11 +384,7 @@ class Trigger(object):
 
 
 def main():
-    try:
-        conf = config.Configuration()
-    except ConfigurationError as e:
-        LOG.error(e.message)
-        raise SystemExit(e.errorno)
+    conf = config.Configuration()
     trigger = Trigger(conf)
     trigger.main(sys.argv[0], sys.argv[1:])
 
